<?php
/*--------------------------------------------------------------------------------------------------
    ContentZoneService.php 2019-07-12
    Gambio GmbH
    http://www.gambio.de
    Copyright (c) 2019 Gambio GmbH
    Released under the GNU General Public License (Version 2)
    [http://www.gnu.org/licenses/gpl-2.0.html]
    --------------------------------------------------------------------------------------------------
 */

namespace Gambio\StyleEdit\Core\Components\ContentZone\Services;

use FileNotFoundException;
use Gambio\StyleEdit\Core\Components\ContentZone\Entities\ContentZoneData;
use Gambio\StyleEdit\Core\Components\ContentZone\Entities\ContentZoneOption;
use Gambio\StyleEdit\Core\Components\ContentZone\Repositories\ContentZoneRepository;
use Gambio\StyleEdit\Core\Language;
use LanguageHelperInterface;

/**
 * Class ContentZoneService
 * @package Gambio\StyleEdit\Core\Components\ContentZone\Services
 */
class ContentZoneService
{
    /**
     * @var ContentZoneRepository
     */
    protected $contentZoneRepository;
    /**
     * @var LanguageHelperInterface
     */
    protected $languageHelper;
    
    
    /**
     * ContentZoneService constructor.
     *
     * @param ContentZoneRepository   $contentZoneRepository
     * @param LanguageHelperInterface $languageHelper
     */
    public function __construct(ContentZoneRepository $contentZoneRepository, LanguageHelperInterface $languageHelper)
    {
        $this->contentZoneRepository = $contentZoneRepository;
        $this->languageHelper        = $languageHelper;
    }
    
    
    /**
     * @param ContentZoneOption $option
     *
     * @throws FileNotFoundException
     */
    public function save(ContentZoneOption $option): void
    {
        
        //inside the method whe have to call me persist method of the options
        $this->contentZoneRepository->saveContentZoneData($option);
        
        $languageCodes = $this->languageHelper->getActiveLanguageCodes();
        foreach ($languageCodes as $languageId => $code) {
            $this->contentZoneRepository->saveContentZoneTemplate($option, new Language($code, $languageId));
        }
    }
    
    
    /**
     * @return ContentZoneData
     * @throws FileNotFoundException
     */
    public function contentZoneData(): ContentZoneData
    {
        return $this->contentZoneRepository->getContentZoneData();
    }
}
