<?php
/*--------------------------------------------------------------------------------------------------
    DependencyInjector.php 2019-08-29
    Gambio GmbH
    http://www.gambio.de
    Copyright (c) 2019 Gambio GmbH
    Released under the GNU General Public License (Version 2)
    [http://www.gnu.org/licenses/gpl-2.0.html]
    --------------------------------------------------------------------------------------------------
 */

namespace Gambio\StyleEdit;

use ContentReadServiceInterface;
use ContentWriteServiceInterface;
use FilesystemAdapter;
use Gambio\GX\Services\System\ThemeSettings\ThemeSettingsService;
use Gambio\StyleEdit\Core\Components\ProductSearchBox\Entities\CategorySearchBoxOption;
use Gambio\StyleEdit\Core\Components\ProductSearchBox\Entities\ProductSearchBoxOption;
use Gambio\StyleEdit\Core\Language;
use Gambio\StyleEdit\Core\SingletonPrototype;
use GmConfigurationServiceInterface;
use LanguageService;
use League\Flysystem\Adapter\Local;
use League\Flysystem\Filesystem;
use MainFactory;
use StaticGXCoreLoader;
use WidgetRegistrar;

/**
 * Class DependencyInjector
 * @package Gambio\StyleEdit\Api
 */
class DependencyInjector
{
    private static function includeExternalFiles($basedir)
    {
        require_once $basedir . '/vendor/autoload.php';
        require_once $basedir . '/GXEngine/Shared/Types/StringType.inc.php';
        require_once $basedir . '/GXEngine/Shared/Types/IntType.inc.php';
        require_once $basedir . '/GXEngine/Shared/Types/Interfaces/IdInterface.inc.php';
        require_once $basedir . '/GXEngine/Shared/Types/IdType.inc.php';
        require_once $basedir . '/system/core/MainAutoloader.inc.php';
        require_once $basedir . '/system/core/MainFactory.inc.php';
        require_once $basedir . '/system/core/caching/DataCache.inc.php';
        require_once $basedir . '/GXMainComponents/Services/Core/Content/Services/ContentWriteServiceInterface.inc.php';
    }
    
    
    public static function inject(): void
    {
        /** @var StyleEditConfiguration $settings */
        $settings = SingletonPrototype::instance()->get(StyleEditConfiguration::class);
        self::includeExternalFiles($settings->baseFolderPath());
        
        SingletonPrototype::instance()->setUp(\LanguageHelperInterface::class,
            static function () {
                return MainFactory::create('LanguageHelper', StaticGXCoreLoader::getDatabaseQueryBuilder());
            });
        
        SingletonPrototype::instance()->setUp(WidgetRegistrar::class,
            static function () {
                return MainFactory::create(WidgetRegistrar::class);
            });
        
        SingletonPrototype::instance()->setUp(ContentWriteServiceInterface::class,
            static function () {
                return \StaticGXCoreLoader::getService('ContentWrite');
            });
        
        SingletonPrototype::instance()->setUp(\CacheControl::class,
            static function () {
                return MainFactory::create_object('CacheControl');
            });
        
        SingletonPrototype::instance()->setUp(ContentReadServiceInterface::class,
            static function () {
                return \StaticGXCoreLoader::getService('ContentRead');
            });
        
        SingletonPrototype::instance()->setUp(GmConfigurationServiceInterface::class,
            static function () {
                return \StaticGXCoreLoader::getService('GmConfiguration');
            });
        
        SingletonPrototype::instance()->setUp(GmConfigurationServiceInterface::class,
            static function () {
                return \StaticGXCoreLoader::getService('GmConfiguration');
            });
        
        SingletonPrototype::instance()->setUp(\ThemeControl::class, static function() {
                return StaticGXCoreLoader::getThemeControl();
        });
        
        SingletonPrototype::instance()->setUp('ProductsearchboxOption',
            static function () {
                return SingletonPrototype::instance()->get(ProductSearchBoxOption::class);
            });
        
        SingletonPrototype::instance()->setUp('CategorysearchboxOption',
            static function () {
                return SingletonPrototype::instance()->get(CategorySearchBoxOption::class);
            });
        
        SingletonPrototype::instance()->setUp(LanguageService::class,
            static function () {
                $language = SingletonPrototype::instance()->get(Language::class)->id();
                
                return MainFactory::create(LanguageService::class, $language);
            });
        
        SingletonPrototype::instance()->setUp(ThemeSettingsService::class,
            static function () {
                return StaticGXCoreLoader::getService('ThemeSettings');
            });
        
        SingletonPrototype::instance()->setUp(FilesystemAdapter::class,
            static function () use ($settings) {
                $filesystemAdapter = new Local($settings->themesFolderPath(), LOCK_EX, Local::DISALLOW_LINKS, [
                    'file' => [
                        'public'  => 0777,
                        'private' => 0700,
                    ],
                    'dir'  => [
                        'public'  => 0777,
                        'private' => 0700,
                    ]
                ]);
                $filesystem        = new Filesystem($filesystemAdapter);
                
                return MainFactory::create(FilesystemAdapter::class, $filesystem);
            });
        
        SingletonPrototype::instance()->setUp('FilesystemAdapterShopRoot',
            static function () {
                $filesystemAdapter = new Local(SHOP_ROOT, LOCK_EX, Local::DISALLOW_LINKS, [
                    'file' => [
                        'public'  => 0777,
                        'private' => 0700,
                    ],
                    'dir'  => [
                        'public'  => 0777,
                        'private' => 0700,
                    ]
                ]);
                $filesystem        = new Filesystem($filesystemAdapter);
                
                return MainFactory::create(FilesystemAdapter::class, $filesystem);
            });
    }
    
}