<?php
/*--------------------------------------------------------------------------------------------------
    ProductListContentViewGenerator.php 2019-09-05
    Gambio GmbH
    http://www.gambio.de
    Copyright (c) 2019 Gambio GmbH
    Released under the GNU General Public License (Version 2)
    [http://www.gnu.org/licenses/gpl-2.0.html]
    --------------------------------------------------------------------------------------------------
 */

/**
 * Class representing the content view for the product list widget
 */
class ProductListContentViewGenerator
{
    /**
     * Generate the HTML output of the product slider
     *
     * @param array $products Product array
     * @param string $elementId Element HTML ID
     * @param string $template Template file
     * @param string $elementClassName Element HTML class name
     * @param array $swiperBreakpoints
     *
     * @return string
     */
    public static function generate(
        array $products,
        string $elementId,
        string $template,
        string $elementClassName = '',
        array $swiperBreakpoints = []
    ) {
        $data = [
            "id"                     => $elementId,
            "hoverable"              => true,
            "template"               => $template,
            "truncate"               => "1",
            "showRating"             => true,
            "fullscreenPage"         => false,
            "showManufacturerImages" => "true",
            "showProductRibbons"     => "true",
            "products"               => $products,
            "swiperOptions"          => [
                "slidesPerView" => 5,
                "autoplay" => false,
                'breakpoints' => $swiperBreakpoints
            ]
        ];
    
        if (StaticGXCoreLoader::getThemeControl()->isThemeSystemActive() === false) {
        
            $data ['template'] = 'snippets/product_listing/' . $template;
        }
    
        //  If theme is active MainFactory will create a ProductsSwiperThemeContentView class
        $contentView = MainFactory::create_object(ProductsSwiperContentView::class, [$data]);
        $result      = $contentView->get_html();
        
        $script = <<<HTML
const imageElement = this;
const containerElement = imageElement.parentNode;

const hoverElement = containerElement.querySelector('[data-gambio-widget=\'product_hover\']');
const swiperElement = hoverElement.querySelector('[data-gambio-widget=\'swiper\']');

if ('{$elementClassName}'.length) {
    swiperElement.classList.add('{$elementClassName}');
}

const initialize = () => {
    window.gambio.widgets.init($(swiperElement));
    window.gambio.widgets.init($(hoverElement));
    imageElement.remove();
}

if (window.gambio) {
    initialize();
    return;
}

window.addEventListener('JSENGINE_INIT_FINISHED', initialize);
HTML;
        
        $result .= <<<HTML
<img src="/images/logos/email_logo.gif" style="opacity: 0;" alt="" onload="$script" />
HTML;
        
        return $result;
    }
}